@@ -15,6 +15,12 @@ class ESpan(Span):
         espan.end_character = espan.end_char
         espan.fixed_text = espan.text
         espan.original_text = espan.text
+        if Span.has_extension("suggestions"):
+            espan.original_suggestions = span._.suggestions
+            espan.is_deletion = len(span._.suggestions) and span._.suggestions[0] == ""
+        else:
+            espan.original_suggestions = []
+            espan.is_deletion = False
         return espan
 
     def __getattribute__(self, item):
